TransformedExt

Trait TransformedExt 

pub trait TransformedExt: Sized {
    // Provided method
    fn transformed<G>(self, transform: G) -> Transformed<Self, G> { ... }
}
Extension methods for attaching an exact transform representation to a value.

Provided Methods

fn transformed<G>(self, transform: G) -> Transformed<Self, G>

Return self wrapped with transform stored exactly as G.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors